@@ -195,11 +195,19 @@ documentation.
 
 The first convention says that all documentation for
 PDL functions appears in the POD section introduced
-by
+by one of the following:
 
   =head1 FUNCTIONS
+  =head1 OPERATORS
+  =head1 METHODS
+  =head1 CONSTRUCTORS
 
-Individual functions in this section are introduced by
+If you're documenting an object-oriented interface to a class
+that your module defines, you should use METHODS and CONSTRUCTORS
+as appropriate.  If you are simply adding functions to PDL,
+use FUNCTIONS and OPERATORS as appropriate.
+
+Individual functions or methods in these section are introduced by
 
   =head2 funcname
 
@@ -551,11 +559,13 @@ sub search {
   $sort = 0 unless defined $sort;
   my $hash = $this->ensuredb;
   my @match = ();
+
   $pattern = $this->checkregex($pattern);
+
   while (my ($key,$val) = each %$hash) {
     for (@$fields) {
-      if (($_ eq 'Name' && $key =~ /$pattern/) ||
-	  (defined $val->{$_} && $val->{$_} =~ /$pattern/)) {
+      if (($_ eq 'Name' && $key =~ /$pattern/i) ||
+	  (defined $val->{$_} && $val->{$_} =~ /$pattern/i)) {
 	$val = $hash->{$val->{Crossref}}
 	  if defined $val->{Crossref} && defined $hash->{$val->{Crossref}};
 	push @match, [$key,$val];
@@ -573,13 +583,14 @@ sub search {
 # where the pairs of '/' can be replaced by any other pair of matching
 # characters
 # if the expression doesn't start with 'm' followed by a nonalphanumeric
-# character return as is
+# character,  return as-is
 sub checkregex {
   my ($this,$regex) = @_;
   return "(?i)$regex" unless $regex =~ /^m[^a-z,A-Z,0-9]/;
   my $sep = substr($regex,1,1);
   substr($regex,0,2) = '';
-  $sep = '\\'.$sep; # quote separator just in case
+  $sep = '(?<!\\\\)\\'.$sep; # Avoid '\' before the separator 
+
   my ($pattern,$mod) = split($sep,$regex,2);
   barf "unknown regex modifiers '$mod'" if $mod && $mod !~ /[imsx]+/;
   $pattern = "(?$mod)$pattern" if $mod;
@@ -685,8 +696,9 @@ sub scantree {
   my $sub = sub { if (($File::Find::name =~ /[.]pm$/ &&
 		      $File::Find::name !~ /PP.pm/ &&
 		      $File::Find::name !~ m|Pod/Parser.pm| &&
-		      $File::Find::dir !~ m#/PP|/Gen#) or
-		       $File::Find::name =~ /[.]pod$/){
+		      $File::Find::dir !~ m#/PP|/Gen#) or (
+		       $File::Find::name =~ /[.]pod$/ && 
+                       $File::Find::name !~ /Index[.]pod$/)){
        printf "%-20s", $_.'...';
        my $n = $this->scan($File::Find::name,$verbose); # bind $this lexically
        print "\t$n functions\n";
