@@ -7,6 +7,10 @@ PDL::IO::FlexRaw -- A flexible binary i/o format for PerlDL.
 	use PDL;
 	use PDL::IO::FlexRaw;
 
+        # To obtain the header for reading (if multiple files use the
+        # same header, for example):
+        $hdr = PDL::IO::FlexRaw::_read_flexhdr("filename.hdr")
+
         ($x,$y,...) = readflex("filename" [, $hdr])
         ($x,$y,...) = mapflex("filename" [, $hdr] [, $opts])
 
@@ -207,7 +211,18 @@ Memory map a binary file with flexible format specification
 
  ($x,$y,...) = mapflex("filename" [, $hdr] [, $opts])
 
+=head2 _read_flexhdr
 
+Read a FlexRaw header file and return a header structure.
+
+=for usage
+
+ $hdr = PDL::IO::FlexRaw::_read_flexhdr($file)
+
+Note that C<_read_flexhdr> is supposed to be an internal function.  It
+was not originally documented and it is not tested.  However, there
+appeared to be no other method for obtaining a header structure from
+a file, so I figured I would write a small bit of documentation on it.
 
 =head1 AUTHOR
 
@@ -218,6 +233,7 @@ conditions. For details, see the file COPYING in the PDL
 distribution. If this file is separated from the PDL distribution,
 the copyright notice should be included in the file.
 
+Documentation contributions copyright (C) David Mertens, 2010.
 
 =cut
 
@@ -335,7 +351,7 @@ sub readchunk {
     my ($d, $pdl, $len, $name) = @_;
     print "Reading $len at $offset from $name\n"
       if $PDL::FlexRaw::verbose;
-    $d->read($ {$pdl->get_dataref},$len) == $len
+    read($d, ${$pdl->get_dataref}, $len) == $len
 	or barf "Couldn't read enough data from '$name'";
     $pdl->upd_data();
     $offset += $len;
@@ -363,7 +379,7 @@ sub mapchunk {
 
 sub readflex {
     barf 'Usage ($x,$y,...) = readflex("filename"|FILEHANDLE [, \@hdr])'
-	if $#_ > 1;
+		if $#_ > 1;
     my ($name,$h) = @_;
     my ($hdr, $pdl, $len, @out, $chunk, $chunkread, $data);
     local ($offset) = 0;
@@ -372,35 +388,34 @@ sub readflex {
 
     # Test if $name is a file handle
     if (defined fileno($name)) {
-	$d = $name;
-	binmode($d); 
+		$d = $name;
+		binmode($d); 
     }
     else {
-    if ($name =~ s/\.gz$// || $name =~ s/\.Z$// ||
-	(! -e $name && (-e $name.'.gz' || -e $name.'.Z'))) {
-	$data = "gzip -dcq $name |";
-	$zipt = 1;
-    } else {
-	$data = $name;
-    }
+		if ($name =~ s/\.gz$// || $name =~ s/\.Z$// ||
+			(! -e $name && (-e $name.'.gz' || -e $name.'.Z'))) {
+			$data = "gzip -dcq $name |";
+			$zipt = 1;
+		} else {
+			$data = $name;
+		}
 
-    my ($size) = (stat $name)[7];
-	$d = new FileHandle $data
-	or barf "Couldn't open '$data' for reading";
-    binmode $d;
-    if ($#_ == 0) {
-	$h = _read_flexhdr("$name.hdr");
-    }
+		my ($size) = (stat $name)[7];
+		$d = new FileHandle $data
+		or barf "Couldn't open '$data' for reading";
+		binmode $d;
+		$h = _read_flexhdr("$name.hdr")
+			unless $h;
     }
 
 # Go through headers which reconfigure
     foreach $hdr (@$h) {
-	my ($type) = $hdr->{Type};
-	if ($type eq 'swap') {
-	    $swapbyte = 1;
-	} elsif ($type ne 'f77') {
-	    last;
-	}
+		my ($type) = $hdr->{Type};
+		if ($type eq 'swap') {
+			$swapbyte = 1;
+		} elsif ($type ne 'f77') {
+			last;
+		}
     }
 
 READ:
