@@ -25,6 +25,10 @@
 #define PI_NUMB     (3.1415926535897932384626433832795)
 #endif
 
+#ifndef M_PI
+#define M_PI PI_NUMB
+#endif
+
 /* declare functions */
 
 double
